︠e3e4ea37-a565-4579-9e6e-eb2c4149fab5i︠
%md
Here I record some computations with the modular curve $X_{ns}(13)$ I did a few years ago. Here's the (affine) equation of the curve:
︡14f66023-716c-4233-8299-b48caba5abc9︡{"done":true,"md":"Here I record some computations with the modular curve $X_{ns}(13)$ I did a few years ago. Here's the (affine) equation of the curve:"}
︠875936f8-11de-41dc-995f-27cac91d383bs︠

R.<x,y>=PolynomialRing(ZZ, 2)

F=(-y-1)*x^3+(2*y^2+y)*x^2+(-y^3+y^2-2*y+1)*x+(2*y^2-3*y)
F_Q = F.change_ring(QQ)
X = Curve(F_Q)
X
X.genus()
︡4287258d-df34-4e11-8ca3-7aea11e4fab4︡{"stdout":"Affine Plane Curve over Rational Field defined by -x^3*y + 2*x^2*y^2 - x*y^3 - x^3 + x^2*y + x*y^2 - 2*x*y + 2*y^2 + x - 3*y\n"}︡{"stdout":"3"}︡{"stdout":"\n"}︡{"done":true}︡
︠3c8e5bb3-2a1d-4bed-9b28-e0da191f7cdai︠
%md 
We check that the (affine) curve has good reduction outside $p=13$:
︡4ff4722e-2244-4db9-8ed1-5534dedd21d9︡{"done":true,"md":"We check that the (affine) curve has good reduction outside $p=13$:"}
︠b499ae5a-077e-4896-bfbb-2f35ea3a8989s︠
Fy = F.derivative(y)
Delta_y = F.resultant(Fy)
Delta_y
︡e0f79d53-fd26-451a-abf2-29667526e383︡{"stdout":"-8*y^9 + 72*y^7 + 22*y^6 - 220*y^5 - 151*y^4 + 114*y^3 + 51*y^2 - 40*y - 15\n"}︡{"done":true}︡
︠b54a39ae-90e1-4a22-ac12-37fbc5f0a45cs︠
S.<z> = QQ['y']
Delta = S(Delta_y)   # we want Delta to be an element of an univariate polynomial ring
Delta
︡43844539-1eaf-4aa6-835e-977f6fbb06ee︡{"stdout":"-8*y^9 + 72*y^7 + 22*y^6 - 220*y^5 - 151*y^4 + 114*y^3 + 51*y^2 - 40*y - 15\n"}︡{"done":true}︡
︠147227b6-8c0f-4404-8c8a-4d914bdab729s︠
Delta.discriminant().factor()
︡d02dec5b-4d00-4425-9bc8-514d2e626b7b︡{"stdout":"-1 * 2^16 * 5 * 13^6 * 43^2 * 15199 * 18959^2\n"}︡{"done":true}︡
︠c5cbca09-5d26-4351-9894-296fc06697cfi︠
%md
These (and also $p=3$) are the primes where we may have bad reduction. We check this in each case separately:
︡6cc15358-3a6a-4b79-8dcf-a09b49c7d70e︡{"done":true,"md":"These (and also $p=3$) are the primes where we may have bad reduction. We check this in each case separately:"}
︠ae52ea73-f175-4268-887e-44f594586d87︠
bad_primes = [2, 3, 5, 13, 43, 15199, 18959]
for p in bad_primes:
    Fb = F.change_ring(GF(p))
    Xb = Curve(Fb)
    print "X is smooth at %s: %s "%(p, Xb.is_smooth())
︡11b11500-270f-45c9-86b1-fe265b04a0b9︡{"stdout":"X is smooth at 2: True \nX is smooth at 3: True \nX is smooth at 5: True \nX is smooth at 13: False \nX is smooth at 43: True \nX is smooth at 15199: True \nX is smooth at 18959: True \n"}︡{"done":true}︡
︠52e7e7fc-e26a-4ba5-85c5-53ed366e1098i︠
%md 
Now we know that we have good reduction outside $p=13$. To understand the reduction at $p=13$ we first move the singularity to the origin.
︡3d0f2236-64f8-4f96-86a3-6d8cd298ff6a︡{"done":true,"md":"Now we know that we have good reduction outside $p=13$. To understand the reduction at $p=13$ we first move the singularity to the origin."}
︠ce8b6f1d-ec20-478c-bfbc-d9fc16d4b3e7︠
Fb = F.change_ring(GF(13))
Xb = Curve(Fb)
Xb.singular_points()
︡3378c033-728c-4e56-8ce1-b87a77ad2dcb︡{"stdout":"[(7, 5)]\n"}︡{"done":true}︡
︠9b026cf6-be06-4b20-b44e-8b196ba59bc7︠
F = F(x+7, y+5)
Fy = F.derivative(y)
Delta = S(F.resultant(Fy))
Deltab = Delta.change_ring(GF(13))
Deltab
︡023dc55f-fb41-4453-8498-4a99f1cddf0c︡{"stdout":"5*y^9 + 4*y^8 + 9*y^7\n"}︡{"done":true}︡
︠229f4042-c497-476a-a40b-01fc1b555558i︠
%md
We see that $7$ of the $10$ branch points specialized to $y=0$. In order to see how to separate them by a change of coordinates we 
look at the Newton polygon of $\Delta$ with respect to the $13$-adic valuation. Recall that $\Delta=0$ is the branch locus of the cover $X\to\mathbb{P}^1_{\mathbb{Q}}$ given by the $y$-coordinate. 
︡9fb6e449-e8da-41fe-b2de-b48c6201217c︡{"done":true,"md":"We see that $7$ of the $10$ branch points specialized to $y=0$. In order to see how to separate them by a change of coordinates we \nlook at the Newton polygon of $\\Delta$ with respect to the $13$-adic valuation. Recall that $\\Delta=0$ is the branch locus of the cover $X\\to\\mathbb{P}^1_{\\mathbb{Q}}$ given by the $y$-coordinate."}
︠633ae1a1-89db-4e3a-91b9-bafd1820a27cs︠
from mac_lane import *
from sage.geometry.newton_polygon import NewtonPolygon
v_13 = pAdicValuation(QQ, 13)
NP = NewtonPolygon([(i, v_13(Delta[i])) for i in range(Delta.degree()+1)])
NP
NP.slopes()
︡a06ae7a2-9a0c-43ee-a17d-b014ba3ec34a︡{"stdout":"Finite Newton polygon with 2 vertices: (0, 0), (9, 0)\n"}︡{"stdout":"[0, 0, 0, 0, 0, 0, 0, 0, 0]\n"}︡{"done":true}︡
︠2d582db2-f21b-494e-8ef1-4da048a304d1i︠
%md 
We see that we can separate the branch point by a substitution $y = 13^{1/7}y_1$.
︡d98c20a3-4758-4964-9a3d-96009a8e9cf0︡{"done":true,"md":"We see that we can separate the branch point by a substitution $y = 13^{1/7}y_1$."}
︠f0390a64-0154-432e-828b-7402a56fb1c7s︠
K.<pi> = QQ.extension(z^7-13)
vK = v_13.extension(K)
F1 = F(x, pi*y)
F1
F1b = F1.map_coefficients(lambda c: vK.reduce(c), vK.residue_field())
F1b
︡f4369b27-4e06-4767-8a25-3ef589ab1236︡{"stdout":"(-pi)*x^3*y + (2*pi^2)*x^2*y^2 + (-pi^3)*x*y^3 - x^3 + (pi)*x^2*y + (pi^2)*x*y^2 + (-2*pi)*x*y + (2*pi^2)*y^2 + x + (-3*pi)*y\n"}︡{"stdout":"-x^3 + x\n"}︡{"done":true}︡
︠775fc94d-85a2-41dc-9485-865059d89d8ai︠
%md 
This calculation shows that there are two irreducible components on the special fiber of the model obtained by the substitution $y = \pi\cdot y_1$, followed by a *normalization* step. To make the normalization step more explicit, we use valuation on the function field of $X_K$ which extend the base valuation $v_K$ and whose residue field has dimension one. 
︡fc3313f8-1cf7-4ce0-b6f2-a800cd8ad3bf︡{"done":true,"md":"This calculation shows that there are two irreducible components on the special fiber of the model obtained by the substitution $y = \\pi\\cdot y_1$, followed by a *normalization* step. To make the normalization step more explicit, we use valuation on the function field of $X_K$ which extend the base valuation $v_K$ and whose residue field has dimension one."}
︠a37c4a60-ea38-47ac-88e7-e70f4ed00fdf︠
︡8bbb44c6-05e3-40a3-826f-b2fc715f9cc6︡
︠ec1c5de0-0dab-4ab0-b6fd-a6b542dabccb︠
F1
F1.parent()
︡684c58f4-2412-43fa-97f3-e91e1e69df3b︡{"stdout":"(-pi)*x^3*y + (2*pi^2)*x^2*y^2 + (-pi^3)*x*y^3 - 6*x^3 + (14*pi^2)*x*y^2 + (-7*pi^3)*y^3 - 71*x^2 + (80*pi)*x*y + (2*pi^2)*y^2 - 221*x + (234*pi)*y - 91\n"}︡{"stdout":"Multivariate Polynomial Ring in x, y over Number Field in pi with defining polynomial y^7 - 13\n"}︡{"done":true}︡
︠eca2f9c3-a569-48ce-8a6a-0c00cc2a8b73s︠
F = F(x+7, y+5)
F
︡4eab9ed5-740c-4fff-adf9-cb78fc25ef10︡{"stdout":"-x^3*y + 2*x^2*y^2 - x*y^3 - 6*x^3 + 14*x*y^2 - 7*y^3 - 71*x^2 + 80*x*y + 2*y^2 - 221*x + 234*y - 91\n"}︡{"done":true}︡
︠6faf858d-6fa3-48d6-9a3b-e9bfcc3426a3︠










